# 📜 abadpour

📜 `abadpour` is an [`@ai`](https://github.com/kamangir/bluer-ai) plugin for my CV/resume, in two versions: [compact](./pdf/arash-abadpour-resume.pdf) and [full](./pdf/arash-abadpour-resume-full.pdf).

## installation

```bash
pip install abadpour
```

# aliases

[abadpour](./abadpour/docs/abadpour.md).

---


[![pylint](https://github.com/kamangir/abadpour/actions/workflows/pylint.yml/badge.svg)](https://github.com/kamangir/abadpour/actions/workflows/pylint.yml) [![pytest](https://github.com/kamangir/abadpour/actions/workflows/pytest.yml/badge.svg)](https://github.com/kamangir/abadpour/actions/workflows/pytest.yml) [![bashtest](https://github.com/kamangir/abadpour/actions/workflows/bashtest.yml/badge.svg)](https://github.com/kamangir/abadpour/actions/workflows/bashtest.yml) [![PyPI version](https://img.shields.io/pypi/v/abadpour.svg)](https://pypi.org/project/abadpour/) [![PyPI - Downloads](https://img.shields.io/pypi/dd/abadpour)](https://pypistats.org/packages/abadpour)

built by 🌀 [`bluer README`](https://github.com/kamangir/bluer-objects/tree/main/bluer_objects/README), based on 📜 [`abadpour-7.18.1`](https://github.com/kamangir/abadpour).
